arib-cli 0.3.0

Reads the signalling of ARIB broadcasts, as an example of the arib crate
arib-cli-0.3.0 is not a library.

A command line tool reading ARIB broadcasts, written as an example of the arib crate.